==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette pétition. Êtes-vous sûre de vouloir continuer ?',
	'aucune_signature' => 'Aucune signature',

	// B
	'bouton_checkbox_envoi_message' => 'possibilité d’envoyer un message',
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web',
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email',
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web',

	// F
	'filtre' => 'Filtre :',
	'form_pet_adresse_site' => 'Adresse URL de votre site',
	'form_pet_aucune_signature' => 'Aucune signature ne correspond à ce code…',
	'form_pet_confirmation' => 'Veuillez confirmer votre signature :',
	'form_pet_deja_signe' => 'Vous avez déjà signé ce texte.',
	'form_pet_envoi_mail_confirmation' => 'Un courrier électronique de confirmation vient d’être envoyé à @email@. Vous devrez visiter l’adresse web mentionnée dans ce courrier pour valider votre signature.',
	'form_pet_mail_confirmation' => 'Bonjour,

Vous avez demandé à signer la pétition :
@titre@.

Vous avez fourni les informations suivantes :
    Nom : @nom_email@
    Site : @nom_site@ - @url_site@
    @message@

IMPORTANT...
Pour valider votre signature, il suffit de vous connecter à
l’adresse ci-dessous (dans le cas contraire, votre demande
sera rejetée) :

    @url@


Merci de votre participation
',
	'form_pet_message_commentaire' => 'Un message, un commentaire ?',
	'form_pet_nom_site2' => 'Nom de votre site web', # enlever le gras
	'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.',
	'form_pet_probleme_technique' => 'Problème technique, les signatures sont temporairement suspendues.',
	'form_pet_signature_validee' => 'Votre signature est validée. Merci !',
	'form_pet_site_deja_enregistre' => 'Ce site est déjà enregistré',
	'form_pet_url_invalide' => 'L’URL que vous avez indiquée n’est pas valide.',
	'form_pet_votre_email' => 'Votre adresse email',
	'form_pet_votre_nom' => 'Votre nom',
	'form_pet_votre_site' => 'Si vous avez un site Web, vous pouvez l’indiquer ci-dessous',

	// I
	'icone_relancer_signataire' => 'Relancer la signataire',
	'icone_relancer_signataires' => 'Relancer les signataires',
	'icone_suivi_petitions' => 'Suivre/gérer les pétitions',
	'icone_supprimer_signature' => 'Supprimer cette signature',
	'icone_supprimer_signatures' => 'Supprimer les signatures',
	'icone_valider_signature' => 'Valider cette signature',
	'icone_valider_signatures' => 'Valider les signatures',
	'info_adresse_email' => 'ADRESSE EMAIL :',
	'info_fonctionnement_petition' => 'Fonctionnement de la pétition :',
	'info_signature_supprimee' => 'Signature supprimée',
	'info_signature_supprimee_erreur' => 'Erreur : ce code de suppression ne correspond à aucune signature',
	'info_site_web' => 'SITE WEB :',
	'info_texte_message' => 'Texte de votre message :',

	// L
	'lien_reponse_article' => 'Réponse à l’article',

	// N
	'nombre_signatures' => '@nb@ signatures',

	// S
	'sans_nom' => 'Anonyme',
	'signatures_article' => 'Signatures de l’article :',
	'signatures_aucune' => 'Aucune',
	'signatures_meme_auteur' => 'Les signatures de la même auteure',
	'signatures_meme_site' => 'Les signatures avec le même site',
	'signatures_poubelle' => 'Supprimées',
	'signatures_prop' => 'En attente',
	'signatures_publie' => 'Confirmées',
	'signatures_recherche_label' => 'Rechercher des signatures :',
	'signatures_selection' => 'Sélectionner les signatures :',
	'signatures_toutes' => 'Toutes',
	'statut_poubelle' => 'Supprimée',
	'statut_prop' => 'En attente de validation',
	'statut_publie' => 'Confirmée',

	// T
	'texte_descriptif_petition' => 'Descriptif de la pétition',
	'titre_page_controle_petition' => 'Suivi des pétitions',
	'titre_petition' => 'Pétition',
	'titre_petitions' => 'Pétitions',
	'titre_selection_action' => 'Sélection',
	'titre_signatures_attente' => 'Signatures en attente de validation',
	'titre_signatures_publie' => 'Signatures confirmées',
	'titre_suivi_petition' => 'Suivi des pétitions',
	'tout_voir' => 'Voir toutes les signatures',

	// U
	'une_signature' => '1 signature',

	// V
	'voir_signatures_objet' => 'Voir les signatures'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette pétition. Êtes-vous sûre de vouloir continuer ?',
	'aucune_signature' => 'Aucune signature',

	// B
	'bouton_checkbox_envoi_message' => 'possibilité d’envoyer un message',
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web',
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email',
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web',
	'bouton_radio_activer_petition' => 'Activer la pétition',
	'bouton_radio_pas_petition' => 'Pas de pétition',
	'bouton_radio_petition_activee' => 'Pétition activée',
	'bouton_radio_supprimer_petition' => 'Supprimer la pétition',

	// F
	'filtre' => 'Filtre :',
	'form_pet_adresse_site' => 'Adresse URL de votre site',
	'form_pet_aucune_signature' => 'Aucune signature ne correspond à ce code…',
	'form_pet_confirmation' => 'Veuillez confirmer votre signature :',
	'form_pet_deja_signe' => 'Vous avez déjà signé ce texte.',
	'form_pet_envoi_mail_confirmation' => 'Un courrier électronique de confirmation vient d’être envoyé à @email@. Vous devrez visiter l’adresse web mentionnée dans ce courrier pour valider votre signature.',
	'form_pet_mail_confirmation' => 'Bonjour,

Vous avez demandé à signer la pétition :
@titre@.

Vous avez fourni les informations suivantes :
    Nom : @nom_email@
    Site : @nom_site@ - @url_site@
    @message@

IMPORTANT...
Pour valider votre signature, il suffit de vous connecter à
l’adresse ci-dessous (dans le cas contraire, votre demande
sera rejetée) :

    @url@


Merci de votre participation
',
	'form_pet_message_commentaire' => 'Un message, un commentaire ?',
	'form_pet_nom_site2' => 'Nom de votre site web', # enlever le gras
	'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.',
	'form_pet_probleme_technique' => 'Problème technique, les signatures sont temporairement suspendues.',
	'form_pet_signature_validee' => 'Votre signature est validée. Merci !',
	'form_pet_site_deja_enregistre' => 'Ce site est déjà enregistré',
	'form_pet_url_invalide' => 'L’URL que vous avez indiquée n’est pas valide.',
	'form_pet_votre_email' => 'Votre adresse email',
	'form_pet_votre_nom' => 'Votre nom',
	'form_pet_votre_site' => 'Si vous avez un site Web, vous pouvez l’indiquer ci-dessous',

	// I
	'icone_relancer_signataire' => 'Relancer la signataire',
	'icone_relancer_signataires' => 'Relancer les signataires',
	'icone_suivi_petitions' => 'Suivre/gérer les pétitions',
	'icone_supprimer_signature' => 'Supprimer cette signature',
	'icone_supprimer_signatures' => 'Supprimer les signatures',
	'icone_valider_signature' => 'Valider cette signature',
	'icone_valider_signatures' => 'Valider les signatures',
	'info_adresse_email' => 'ADRESSE EMAIL :',
	'info_fonctionnement_petition' => 'Fonctionnement de la pétition :',
	'info_signature_supprimee' => 'Signature supprimée',
	'info_signature_supprimee_erreur' => 'Erreur : ce code de suppression ne correspond à aucune signature',
	'info_site_web' => 'SITE WEB :',
	'info_texte_message' => 'Texte de votre message :',

	// L
	'lien_reponse_article' => 'Réponse à l’article',

	// N
	'nombre_signatures' => '@nb@ signatures',

	// S
	'sans_nom' => 'Anonyme',
	'signatures_article' => 'Signatures de l’article :',
	'signatures_aucune' => 'Aucune',
	'signatures_meme_auteur' => 'Les signatures de la même auteure',
	'signatures_meme_site' => 'Les signatures avec le même site',
	'signatures_poubelle' => 'Supprimées',
	'signatures_prop' => 'En attente',
	'signatures_publie' => 'Confirmées',
	'signatures_recherche_label' => 'Rechercher des signatures :',
	'signatures_selection' => 'Sélectionner les signatures :',
	'signatures_toutes' => 'Toutes',
	'statut_poubelle' => 'Supprimée',
	'statut_prop' => 'En attente de validation',
	'statut_publie' => 'Confirmée',

	// T
	'texte_descriptif_petition' => 'Descriptif de la pétition',
	'titre_page_controle_petition' => 'Suivi des pétitions',
	'titre_petition' => 'Pétition',
	'titre_petitions' => 'Pétitions',
	'titre_selection_action' => 'Sélection',
	'titre_signatures_attente' => 'Signatures en attente de validation',
	'titre_signatures_publie' => 'Signatures confirmées',
	'titre_suivi_petition' => 'Suivi des pétitions',
	'tout_voir' => 'Voir toutes les signatures',

	// U
	'une_signature' => '1 signature',

	// V
	'voir_signatures_objet' => 'Voir les signatures'
);

?>
